==> qiho-center-biz-1.2-sources.jar: com/qiho/center/biz/remoteservice/impl/RemoteLogisticsOrderServiceImpl.java <==
package com.qiho.center.biz.remoteservice.impl;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import cn.com.duiba.wolf.dubbo.DubboResult;

import com.qiho.center.api.dto.PagenationDto;
import com.qiho.center.api.dto.logistics.LogisticsOrderDto;
import com.qiho.center.api.dto.logistics.LogisticsProcessDto;
import com.qiho.center.api.dto.logistics.QueryLogisticsOrderDto;
import com.qiho.center.api.remoteservice.RemoteLogisticsOrderService;
import com.qiho.center.biz.bo.LogisticsOrderBo;
import com.qiho.center.biz.service.LogisticsOrderService;

/**
 * ClassName: RemoteLogisticsOrderServiceImpl <br/>
 * date: 2017年6月3日 下午3:44:25 <br/>
 *
 * @author chencheng
 * @version
 */
@Service
public class RemoteLogisticsOrderServiceImpl implements RemoteLogisticsOrderService {

    private static final Logger   LOG = LoggerFactory.getLogger(RemoteLogisticsOrderServiceImpl.class);
    @Autowired
    private LogisticsOrderService logisticsOrderService;
    @Autowired
    private LogisticsOrderBo      logisticsOrderBo;

    @Override
    public DubboResult<PagenationDto<LogisticsOrderDto>> queryLogisticsOrderPage(QueryLogisticsOrderDto queryItem,
                                                                                 Integer pageNum, Integer pageSize) {
        try {
            PagenationDto<LogisticsOrderDto> page = logisticsOrderService.queryLogisticsOrderPage(queryItem, pageNum,
                                                                                                  pageSize);
            return DubboResult.successResult(page);
        } catch (Exception e) {
            LOG.error("invoke RemoteLogisticsOrderService.queryLogisticsOrderPage failed, queryItem={}, pageNum={}, pageSize={}",
                      queryItem, pageNum, pageSize, e);
            return DubboResult.failResult(e.getMessage());
        }
    }

    @Override
    public DubboResult<Integer> updateBylogisticsId(String logisticsId, String orderStatus) {
        try {
            return DubboResult.successResult(logisticsOrderService.updateBylogisticsId(logisticsId, orderStatus));
        } catch (Exception e) {
            LOG.error("invoke RemoteLogisticsOrderService.updateLogisticsOrderStatusBatch failed, logisticsId={}, orderStatus={}",
                      logisticsId, orderStatus, e);
            return DubboResult.failResult(e.getMessage());
        }
    }

    /**
     * @see com.qiho.center.api.remoteservice.RemoteLogisticsOrderService#findByOrderId(java.lang.String)
     */
    @Override
    public DubboResult<List<LogisticsOrderDto>> findByOrderId(String orderId) {
        try {
            return DubboResult.successResult(logisticsOrderService.findByOrderId(orderId));
        } catch (Exception e) {
            LOG.error("invoke RemoteLogisticsOrderService.findByOrderId failed, orderId={}", orderId, e);
            return DubboResult.failResult(e.getMessage());
        }
    }

    @Override
    public DubboResult<Integer> updateLogisticsOrderStatus(LogisticsOrderDto logisticsOrderDto) {
        try {
            return DubboResult.successResult(logisticsOrderService.update(logisticsOrderDto));
        } catch (Exception e) {
            LOG.error("invoke RemoteLogisticsOrderService.updateLogisticsOrderStatus failed, logisticsOrderDto={}",
                      logisticsOrderDto, e);
            return DubboResult.failResult(e.getMessage());
        }
    }

    @Override
    public DubboResult<List<LogisticsProcessDto>> queryYTOLogisticsProcessByPostId(String postId) {
        try {
            return DubboResult.successResult(logisticsOrderBo.queryYTOLogisticsProcessByPostId(postId));
        } catch (Exception e) {
            LOG.error("invoke RemoteLogisticsOrderService.queryLogisticsProcessByPostId failed, postId={}", postId, e);
            return DubboResult.failResult(e.getMessage());
        }
    }

    @Override
    public DubboResult<Integer> batchSignOrder(String progressKey, List<LogisticsOrderDto> paramList) {
        try {
            return DubboResult.successResult(logisticsOrderBo.batchSignOrder(progressKey, paramList));
        } catch (Exception e) {
            LOG.error("invoke RemoteLogisticsOrderService.batchSignOrder failed, progressKey={}, paramList={}",
                      progressKey, paramList, e);
            return DubboResult.failResult(e.getMessage());
        }
    }

    @Override
    public DubboResult<Boolean> ManualErpLogisticsSyncQueryJob() {
        try {
            logisticsOrderBo.erpLogisticsSyncQuery();
            return DubboResult.successResult(true);
        } catch (Exception e) {
            LOG.error("invoke RemoteLogisticsOrderService.batchSignOrder failed", e);
            return DubboResult.failResult("手动触发失败");
        }
    }

}

==> qiho-center-biz-1.2.4-sources.jar: com/qiho/center/biz/remoteservice/impl/RemoteLogisticsOrderServiceImpl.java <==
package com.qiho.center.biz.remoteservice.impl;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import cn.com.duiba.wolf.dubbo.DubboResult;

import com.qiho.center.api.dto.PagenationDto;
import com.qiho.center.api.dto.logistics.LogisticsOrderDto;
import com.qiho.center.api.dto.logistics.LogisticsProcessDto;
import com.qiho.center.api.dto.logistics.QueryLogisticsOrderDto;
import com.qiho.center.api.remoteservice.RemoteLogisticsOrderService;
import com.qiho.center.biz.bo.LogisticsOrderBo;
import com.qiho.center.biz.service.LogisticsOrderService;

/**
 * ClassName: RemoteLogisticsOrderServiceImpl <br/>
 * date: 2017年6月3日 下午3:44:25 <br/>
 *
 * @author chencheng
 * @version
 */
@Service
public class RemoteLogisticsOrderServiceImpl implements RemoteLogisticsOrderService {

    private static final Logger   LOG = LoggerFactory.getLogger(RemoteLogisticsOrderServiceImpl.class);
    @Autowired
    private LogisticsOrderService logisticsOrderService;
    @Autowired
    private LogisticsOrderBo      logisticsOrderBo;

    @Override
    public DubboResult<PagenationDto<LogisticsOrderDto>> queryLogisticsOrderPage(QueryLogisticsOrderDto queryItem,
                                                                                 Integer pageNum, Integer pageSize) {
        try {
            PagenationDto<LogisticsOrderDto> page = logisticsOrderService.queryLogisticsOrderPage(queryItem, pageNum,
                                                                                                  pageSize);
            return DubboResult.successResult(page);
        } catch (Exception e) {
            LOG.error("invoke RemoteLogisticsOrderService.queryLogisticsOrderPage failed, queryItem={}, pageNum={}, pageSize={}",
                      queryItem, pageNum, pageSize, e);
            return DubboResult.failResult(e.getMessage());
        }
    }

    @Override
    public DubboResult<Integer> updateBylogisticsId(String logisticsId, String orderStatus) {
        try {
            return DubboResult.successResult(logisticsOrderService.updateBylogisticsId(logisticsId, orderStatus));
        } catch (Exception e) {
            LOG.error("invoke RemoteLogisticsOrderService.updateLogisticsOrderStatusBatch failed, logisticsId={}, orderStatus={}",
                      logisticsId, orderStatus, e);
            return DubboResult.failResult(e.getMessage());
        }
    }

    /**
     * @see com.qiho.center.api.remoteservice.RemoteLogisticsOrderService#findByOrderId(java.lang.String)
     */
    @Override
    public DubboResult<List<LogisticsOrderDto>> findByOrderId(String orderId) {
        try {
            return DubboResult.successResult(logisticsOrderService.findByOrderId(orderId));
        } catch (Exception e) {
            LOG.error("invoke RemoteLogisticsOrderService.findByOrderId failed, orderId={}", orderId, e);
            return DubboResult.failResult(e.getMessage());
        }
    }

    @Override
    public DubboResult<Integer> updateLogisticsOrderStatus(LogisticsOrderDto logisticsOrderDto) {
        try {
            return DubboResult.successResult(logisticsOrderService.update(logisticsOrderDto));
        } catch (Exception e) {
            LOG.error("invoke RemoteLogisticsOrderService.updateLogisticsOrderStatus failed, logisticsOrderDto={}",
                      logisticsOrderDto, e);
            return DubboResult.failResult(e.getMessage());
        }
    }

    @Override
    public DubboResult<List<LogisticsProcessDto>> queryYTOLogisticsProcessByPostId(String postId) {
        try {
            return DubboResult.successResult(logisticsOrderBo.queryYTOLogisticsProcessByPostId(postId));
        } catch (Exception e) {
            LOG.error("invoke RemoteLogisticsOrderService.queryLogisticsProcessByPostId failed, postId={}", postId, e);
            return DubboResult.failResult(e.getMessage());
        }
    }

    @Override
    public DubboResult<Integer> batchSignOrder(String progressKey, List<LogisticsOrderDto> paramList) {
        try {
            return DubboResult.successResult(logisticsOrderBo.batchSignOrder(progressKey, paramList));
        } catch (Exception e) {
            LOG.error("invoke RemoteLogisticsOrderService.batchSignOrder failed, progressKey={}, paramList={}",
                      progressKey, paramList, e);
            return DubboResult.failResult(e.getMessage());
        }
    }

    @Override
    public DubboResult<Boolean> ManualErpLogisticsSyncQueryJob() {
        try {
            logisticsOrderBo.erpLogisticsSyncQuery();
            return DubboResult.successResult(true);
        } catch (Exception e) {
            LOG.error("invoke RemoteLogisticsOrderService.batchSignOrder failed", e);
            return DubboResult.failResult("手动触发失败");
        }
    }

    /**
     * @see com.qiho.center.api.remoteservice.RemoteLogisticsOrderService#syncLogisticsStatus()
     */
    @Override
    public DubboResult<Void> syncLogisticsStatus(String logisticsOrderStatus) {
        try {
            new Thread(() -> logisticsOrderService.syncLogisticsStatus(logisticsOrderStatus)).start();
            return DubboResult.successResult(null);
        } catch (Exception e) {
            LOG.error("invoke RemoteLogisticsOrderService.syncLogisticsStatus failed", e);
            return DubboResult.failResult("同步物流状态失败");
        }
    }

}
